summaryrefslogtreecommitdiffstats
path: root/models/login_source.go
diff options
context:
space:
mode:
Diffstat (limited to 'models/login_source.go')
-rw-r--r--models/login_source.go12
1 files changed, 4 insertions, 8 deletions
diff --git a/models/login_source.go b/models/login_source.go
index c43afd58b7..caf1a1dd4f 100644
--- a/models/login_source.go
+++ b/models/login_source.go
@@ -183,14 +183,10 @@ func (source *LoginSource) BeforeSet(colName string, val xorm.Cell) {
}
}
-// AfterSet is invoked from XORM after setting the value of a field of this object.
-func (source *LoginSource) AfterSet(colName string, _ xorm.Cell) {
- switch colName {
- case "created_unix":
- source.Created = time.Unix(source.CreatedUnix, 0).Local()
- case "updated_unix":
- source.Updated = time.Unix(source.UpdatedUnix, 0).Local()
- }
+// AfterLoad is invoked from XORM after setting the values of all fields of this object.
+func (source *LoginSource) AfterLoad() {
+ source.Created = time.Unix(source.CreatedUnix, 0).Local()
+ source.Updated = time.Unix(source.UpdatedUnix, 0).Local()
}
// TypeName return name of this login source type.